@@ -151,11 +151,12 @@ test_that("non-spatial tables can be written to GPKG; #1345", {
   # demo:
   #a = data.frame(a = c(1L,-3L), b = c("foo", "bar"))
   a = data.frame(a = c(1L,-3L), b = c(3.5, 7.33))
-  expect_silent(write_sf(a, tf, 
+  # generates warnings on GDAL 3.1.1:
+  write_sf(a, tf, 
            layer = "nonspatial_table1",
            driver = "GPKG",
 		   delete_layer = TRUE,
-           layer_options = "ASPATIAL_VARIANT=GPKG_ATTRIBUTES"))
+           layer_options = "ASPATIAL_VARIANT=GPKG_ATTRIBUTES")
   l2 = st_layers(tf)
   expect_true(is.na(l2$geomtype[[2]])) # hence is aspatial
   a2 = as.data.frame(read_sf(tf, "nonspatial_table1"))
